summaryrefslogtreecommitdiffstats
path: root/languages/cpp/simpletype.h
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/simpletype.h')
-rw-r--r--languages/cpp/simpletype.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/languages/cpp/simpletype.h b/languages/cpp/simpletype.h
index 19fb22cc..49b01ee0 100644
--- a/languages/cpp/simpletype.h
+++ b/languages/cpp/simpletype.h
@@ -42,7 +42,7 @@ class SimpleTypeFunctionInterface;
typedef KSharedPtr<SimpleTypeImpl> TypePointer;
-///if this is set, imported items will get their parent set to the node they were acquired through(which may increase the overall count of items, decrease the caching-performance, and may create other problems in locating stuff)
+///if this is set, imported items will get their tqparent set to the node they were acquired through(which may increase the overall count of items, decrease the caching-performance, and may create other problems in locating stuff)
//#define PHYSICAL_IMPORT
enum Repository {
@@ -214,7 +214,7 @@ class SimpleTypeConfiguration {
SimpleType::destroyStore();
}
}
- void invalidate() {
+ void tqinvalidate() {
m_invalid = true;
}
};
@@ -251,7 +251,7 @@ class SimpleTypeImpl : public KShared {
///Returns the template-specialization-string for classes
virtual TQString specialization() const {
- return TQString::null;
+ return TQString();
}
class TemplateParamInfo {
@@ -322,7 +322,7 @@ class SimpleTypeImpl : public KShared {
};
///Sets the parent of the given slave to either this class, or the proxy of this class
virtual void setSlaveParent( SimpleTypeImpl& slave );
void setMasterProxy( TypePointer t ) {
@@ -410,11 +410,11 @@ class SimpleTypeImpl : public KShared {
}
protected:
- virtual void invalidateCache() {}
+ virtual void tqinvalidateCache() {}
;
///Secondary cache also depends on the surrounding
- virtual void invalidateSecondaryCache() {}
+ virtual void tqinvalidateSecondaryCache() {}
virtual void setSecondaryCacheActive( bool active ) {
Q_UNUSED( active );
@@ -422,7 +422,7 @@ class SimpleTypeImpl : public KShared {
///Primary cache is the one associated only with this object. It must only be cleared
///when the object pointed to changes
- virtual void invalidatePrimaryCache( bool onlyNegative = false ) {}
+ virtual void tqinvalidatePrimaryCache( bool onlyNegative = false ) {}
static TQString operatorToString( Operator op );
@@ -480,19 +480,19 @@ class SimpleTypeImpl : public KShared {
return ts;
}
- ///sets the parent-type(type this one is nested in)
- void setParent( TypePointer parent ) {
- if( parent == m_parent ) return;
- invalidateSecondaryCache();
- if ( &( *parent ) == this ) {
+ ///sets the tqparent-type(type this one is nested in)
+ void setParent( TypePointer tqparent ) {
+ if( tqparent == m_parent ) return;
+ tqinvalidateSecondaryCache();
+ if ( &( *tqparent ) == this ) {
kdDebug( 9007 ) << "setSlaveParent error\n" << kdBacktrace() << endl;
return ;
}
- m_parent = parent;
+ m_parent = tqparent;
}
///returns whether the type has template-parameters, or one of the parent-types has template-parameters.
bool usingTemplates() const {
return !m_desc.templateParams().isEmpty() || ( m_parent && m_parent->usingTemplates() );
}
@@ -617,7 +617,7 @@ class SimpleTypeImpl : public KShared {
ExcludeParents = 16,
ExcludeNestedTypes = 32,
ExcludeNamespaces = 64,
- ForgetModeUpwards = 128, ///forgets everything, even NoFail, while passing control to the parent
+ ForgetModeUpwards = 128, ///forgets everything, even NoFail, while passing control to the tqparent
LocateBase = 4 + 8 + 32 + 64 + 128, ///searching in the scope visible while the base-declaration of a class
NoFail = 256,
TraceAliases = 512, ///Stores a copy whenever an alias is applied
@@ -718,8 +718,8 @@ class SimpleTypeImpl : public KShared {
///Returns either itself, or the (namespace-)proxy this type is a slave of.
TypePointer bigContainer();
- ///Returns the parent, eg. the SimpleType this one is nested in.
- SimpleType parent();
+ ///Returns the tqparent, eg. the SimpleType this one is nested in.
+ SimpleType tqparent();
///this must be a reference, so the desc can be manipulated in-place from outside
const TypeDesc& desc();
@@ -779,31 +779,31 @@ class SimpleTypeImpl : public KShared {
///Used to set the include-files that were used to find this type(needed for lazy evaluation of the base-classes)
void setFindIncludeFiles( const IncludeFiles& files );
///Should be called within the parent-namespace/class
virtual void chooseSpecialization( MemberInfo& member );
};
class TypeTrace {
- TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> > m_trace;
+ TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> > m_trace;
public:
- TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> >& trace() {
+ TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> >& trace() {
return m_trace;
};
void prepend( const SimpleTypeImpl::MemberInfo& t, const TypeDesc& tail = TypeDesc() ) {
- m_trace.push_front( QPair< SimpleTypeImpl::MemberInfo, TypeDesc>( t, tail ) );
+ m_trace.push_front( TQPair< SimpleTypeImpl::MemberInfo, TypeDesc>( t, tail ) );
}
void prepend( const TypeTrace& trace, int indent = 0 ) {
/* if( indent != 0 ) {
TQString ind;
for( int a = 0; a < indent; a++ ) ind += " ";
- for( TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> >::const_iterator it = trace.m_trace.end(); it != trace.m_trace.begin(); ) {
+ for( TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> >::const_iterator it = trace.m_trace.end(); it != trace.m_trace.begin(); ) {
--it;
- QPair<SimpleTypeImpl::MemberInfo, TypeDesc> item = *it;
+ TQPair<SimpleTypeImpl::MemberInfo, TypeDesc> item = *it;
item.second.prependDecoration( ind );
m_trace.push_front( item );
}
@@ -322,7 +322,7 @@ class SimpleTypeImpl : public KShared {
};
- ///Sets the parent of the given slave to either this class, or the proxy of this class
+ ///Sets the tqparent of the given slave to either this class, or the proxy of this class
virtual void setSlaveParent( SimpleTypeImpl& slave );
void setMasterProxy( TypePointer t ) {
@@ -480,19 +480,19 @@ class SimpleTypeImpl : public KShared {
}
- ///returns whether the type has template-parameters, or one of the parent-types has template-parameters.
+ ///returns whether the type has template-parameters, or one of the tqparent-types has template-parameters.
bool usingTemplates() const {
return !m_desc.templateParams().isEmpty() || ( m_parent && m_parent->usingTemplates() );
@@ -779,31 +779,31 @@ class SimpleTypeImpl : public KShared {
///Used to set the include-files that were used to find this type(needed for lazy evaluation of the base-classes)
void setFindIncludeFiles( const IncludeFiles& files );
- ///Should be called within the parent-namespace/class
+ ///Should be called within the tqparent-namespace/class
virtual void chooseSpecialization( MemberInfo& member );
};